Processor
=========

.. automodule:: Processor

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   Processor.App
   Processor.process_article
   Processor.processor

